@@ -2,34 +2,22 @@ package Log::Dispatch::Configurator;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = 0.11_02;
+$VERSION = 0.01;
 
 sub new {
     my($class, $file) = @_;
-    bless {
-	file   => $file,
-	_ctime => 0,
-	_watch => 0,
-    }, $class;
+    return bless { file => $file }, $class;
 }
 
-sub parse { }
-
 sub needs_reload {
-    my $self = shift;
-    return $self->{_ctime} < (stat($self->{file}))[9];
+    my($self, $obj) = @_;
+    return $obj->{ctime} < (stat($self->{file}))[9];
 }
 
-sub conf_time {
+sub reload {
     my $self = shift;
-    $self->{_ctime} = shift if @_;
-    $self->{_ctime};
-}
-
-sub should_watch {
-    my $self = shift;
-    $self->{_watch} = shift if @_;
-    return $self->{_watch};
+    my $class = ref $self;
+    return $class->new($self->{file});
 }
 
 sub _abstract_method {
@@ -52,14 +40,9 @@ Log::Dispatch::Configurator - Abstract Configurator class
   package Log::Dispatch::Configurator::Foo;
   use base qw(Log::Dispatch::Configurator);
 
-  # should implement
   sub get_attrs_global { }
   sub get_attrs        { }
 
-  # optional
-  sub parse        { }
-  sub needs_reload { }
-
 =head1 DESCRIPTION
 
 Log::Dispatch::Configurator is an abstract class of config parser. If
